@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2016-01-23'; # DATE
-our $VERSION = '1.49'; # VERSION
+our $DATE = '2016-02-04'; # DATE
+our $VERSION = '1.50'; # VERSION
 
 use 5.010001;
 use strict;
@@ -261,13 +261,21 @@ _
             return undef unless $cmdline;
 
             # since this is common option, at this point we haven't parsed
-            # argument or even read config file. so we need to do that first.
+            # argument or even read config file. let's parse argv first (argv
+            # might set --config-path). then read the config files.
             {
                 # this is not activated yet
                 $r->{read_config} = 1;
 
                 my $res = $cmdline->parse_argv($r);
                 #return undef unless $res->[0] == 200;
+
+                # parse_argv() might decide that it doesn't need to read config
+                # files (e.g. in the case of program having a subcommand and
+                # user does not specify any subcommand name, then it will
+                # shortcut to --help and set skip_parse_subcommand_argv=1). we
+                # don't want that here, we want to force reading config files:
+                $cmdline->_read_config($r) unless $r->{config};
             }
 
             # we are not reading any config file, return empty list
@@ -490,6 +498,7 @@ sub do_completion {
     if ($r->{shell} eq 'bash') {
         require Complete::Bash;
         ($words, $cword) = @{ Complete::Bash::parse_cmdline(undef, undef, {truncate_current_word=>1}) };
+        ($words, $cword) = @{ Complete::Bash::join_wordbreak_words($words, $cword) };
     } elsif ($r->{shell} eq 'fish') {
         require Complete::Fish;
         ($words, $cword) = @{ Complete::Fish::parse_cmdline() };
@@ -974,6 +983,7 @@ sub __gen_iter {
 
     my ($fh, $argspec, $argname) = @_;
     my $schema = $argspec->{schema};
+    $schema = $schema->[1]{of} if $schema->[0] eq 'array';
     my $type = Data::Sah::Util::Type::get_type($schema);
 
     if (Data::Sah::Util::Type::is_simple($schema)) {
@@ -1416,7 +1426,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.49 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-01-23.
+This document describes version 1.50 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-02-04.
 
 =head1 DESCRIPTION
 
@@ -2225,7 +2235,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-CmdLine-Lite>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.
 
 =head1 BUGS
 
